@@ -68,6 +68,8 @@ class Project():
     def __init__(self, _project, _project_name: str):
         self.project_name = _project_name
         self.project = _project
+    def __repr__(self) -> str:
+        return f'project:{self.get_name()}'
 
     def get_self_project(self):
         return self.project
